Learn R Programming

wrspathrow (version 0.1)

wrs1_asc_desc: Worldwide Reference System - 1 (WRS1) SpatialPolygonsDataFrame

Description

Contains polygons of the area of each path and row for the ascending and descending nodes of the WRS1 system.

Arguments

See Also

wrs2_asc_desc